@@ -9,3 +9,6 @@ class Client(object):
 
     def set_api_key(self, api_key):
         self.api_key = api_key
+
+    def get_api_key(self):
+        return self.api_key
